@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: propertyproxy_base.cc,v 1.4 2004/02/13 16:53:19 teebaum Exp $ */
+/* $Id: propertyproxy_base.cc,v 1.4.6.1 2006/05/10 13:12:39 murrayc Exp $ */
 
 /* propertyproxy_base.h
  *
@@ -21,6 +21,9 @@
  */
 
 #include <glibmm/propertyproxy_base.h>
+
+#ifdef GLIBMM_PROPERTIES_ENABLED
+
 #include <glibmm/signalproxy_connectionnode.h>
 #include <glibmm/object.h>
 #include <glibmm/private/object_p.h>
@@ -149,3 +152,4 @@ void PropertyProxy_Base::reset_property_()
 
 } // namespace Glib
 
+#endif //GLIBMM_PROPERTIES_ENABLED
